==> flutter_catalogue_widgets-0.0.15.tar.gz: lib/custom-compositeLandingPage.dart <==
/*
Description:
A widget that creates a layout consisting of an AppBar, Left Navigation Bar and a Tab Bar alongside views for each tab bar.
The widget intakes the following values and properties for each of its 3 components.
1. Parameter for creating an App Bar
2. Icons to be displayed on the App Bar
3. Tabs to be displayed in the Tab Bar
4. User Info to be shows in the Left Nav Bar
5. Items to be displayed in the Left Nav Bar
6. Callback functions for Left Nav Bar.

Imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/composite-widgets/custom-compositeLandingPage.dart';

Usage:
The user will initialize and define variables for each of the Widget Parameters.
The widget can be called in the following manner:

// The object definitions for the widget
    onclickLeftNav(int nIndex) {
      print(nIndex);
    }

    List<TabBarProducts> tabs = [];
    TabBarProducts tab1 = new TabBarProducts(
        "Tab1", Icon(Icons.settings), Container(child: Text('TabView 1')));
    TabBarProducts tab2 = new TabBarProducts(
        "Tab2", Icon(Icons.home), Container(child: Text('TabView 2')));
    tabs.add(tab1);
    tabs.add(tab2);

    List<DrawerListItems> drawerList = [
      DrawerListItems(Icon(Icons.settings), Text('Tab1')),
      DrawerListItems(Icon(Icons.home), Text('Tab2')),
    ];

    DrawerHeaderParameters userInfo = new DrawerHeaderParameters(
      title: 'User Name',
      subtitle: 'User Designation',
    );

    AppBarParameters appBarparams = new AppBarParameters(
        backgroundColor: Colors.red,
        elevation: 5,
        bottomOpacity: 1.0,
        toolbarOpacity: 1.0,
        titleSpacing: 1.0,
        centerTitle: false,
        title: Text('Test'));
    List<Widget> appBarIcons = [
      IconButton(
        icon: Icon(Icons.list),
        tooltip: 'Opens Drawer',
        onPressed: () {},
      ),
      IconButton(
        icon: Icon(Icons.alarm_add),
        tooltip: 'Opens Clock',
        onPressed: () {},
      )
    ];
// Calling the composite layout widget
AppBarWithTabsAndDrawer(appBarparams, appBarIcons, tabs, userInfo,
            drawerList, onclickLeftNav))

Author:
Rishabh Thakur (Composite Widget)
Karan (AppBar)
Ishita (TabBar)
*/

import 'package:flutter/material.dart';
import 'color.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';
import 'custom-appBar.dart';
import 'custom-drawer.dart';
import 'globals.dart';

class AppBarWithTabsAndDrawer extends StatefulWidget {
 final AppBarParameters appBarparams;
 final List<Widget> appBarIcons;
 final List<TabBarProducts> tabsInfo;
 final DrawerHeaderParameters userInfo;
 final List<DrawerListItems> listItems;
 final Function(int) leftNavRouting;
  AppBarWithTabsAndDrawer(this.appBarparams, this.appBarIcons, this.tabsInfo,
      this.userInfo, this.listItems, this.leftNavRouting);

  @override
  State<StatefulWidget> createState() {
    return _TestClass(this.appBarparams, this.appBarIcons, this.tabsInfo,
        this.userInfo, this.listItems, this.leftNavRouting);
  }
}

class _TestClass extends State<AppBarWithTabsAndDrawer>
    with SingleTickerProviderStateMixin {
  AppBarParameters appBarparams;
  List<Widget> appBarIcons;
  List<TabBarProducts> tabsInfo;
  DrawerHeaderParameters userInfo;
  List<DrawerListItems> listItems;
  Function(int) leftNavRouting;
  _TestClass(this.appBarparams, this.appBarIcons, this.tabsInfo, this.userInfo,
      this.listItems, this.leftNavRouting);

  @override
  void initState() {
    super.initState();
    tabControllerForCompositeWidget =
        TabController(initialIndex: 0, vsync: this, length: tabsInfo.length);
  }

  @override
  void dispose() {
    tabControllerForCompositeWidget.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    print(tabsInfo);
    List<Tab> tabList = [];
    List<Widget> tabWidgets = [];
    var tab;
    for (var i = 0; i < tabsInfo.length; i++) {
      tab = new Tab(
          text: tabsInfo[i].text,
          icon: tabsInfo[i].icons != null ? tabsInfo[i].icons : Icons.favorite);
      tabList.add(tab);
    }
    for (var i = 0; i < tabsInfo.length; i++) {
      tab = tabsInfo[i].widget;
      tabWidgets.add(tab);
    }
    // If the user doesn't pass a Tab Bar as part of parameters
    if (appBarparams.bottom == null) {
      appBarparams.bottom = TabBar(
        controller: tabControllerForCompositeWidget,
        labelColor: SalesforceColor.white,
        indicatorColor: SalesforceColor.black,
        unselectedLabelColor: SalesforceColor.orange,
        indicator: BoxDecoration(
          boxShadow: [
            BoxShadow(color: SalesforceColor.orange, offset: cons.offsetDefault)
          ],
          color: SalesforceColor.darkGrey,
        ),
        tabs: tabList,
      );
    }

    return Scaffold(
      drawer: CustomDrawer(listItems, leftNavRouting, userInfo),
      appBar: customAppBar(appBarIcons, appBarparams),
      body: new TabBarView(
        children: tabWidgets,
        controller: tabControllerForCompositeWidget,
      ),
    );
  }
}

==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-compositeLandingPage.dart <==
/*
Description:
A widget that creates a layout consisting of an AppBar, Left Navigation Bar and a Tab Bar alongside views for each tab bar.
The widget intakes the following values and properties for each of its 3 components.
1. Parameter for creating an App Bar
2. Icons to be displayed on the App Bar
3. Tabs to be displayed in the Tab Bar
4. User Info to be shows in the Left Nav Bar
5. Items to be displayed in the Left Nav Bar
6. Callback functions for Left Nav Bar.

Imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/composite-widgets/custom-compositeLandingPage.dart';

Usage:
The user will initialize and define variables for each of the Widget Parameters.
The widget can be called in the following manner:

// The object definitions for the widget
    onclickLeftNav(int nIndex) {
      print(nIndex);
    }

    List<TabBarProducts> tabs = [];
    TabBarProducts tab1 = new TabBarProducts(
        "Tab1", Icon(Icons.settings), Container(child: Text('TabView 1')));
    TabBarProducts tab2 = new TabBarProducts(
        "Tab2", Icon(Icons.home), Container(child: Text('TabView 2')));
    tabs.add(tab1);
    tabs.add(tab2);

    List<DrawerListItems> drawerList = [
      DrawerListItems(Icon(Icons.settings), Text('Tab1')),
      DrawerListItems(Icon(Icons.home), Text('Tab2')),
    ];

    DrawerHeaderParameters userInfo = new DrawerHeaderParameters(
      title: 'User Name',
      subtitle: 'User Designation',
    );

    AppBarParameters appBarparams = new AppBarParameters(
        backgroundColor: Colors.red,
        elevation: 5,
        bottomOpacity: 1.0,
        toolbarOpacity: 1.0,
        titleSpacing: 1.0,
        centerTitle: false,
        title: Text('Test'));
    List<Widget> appBarIcons = [
      IconButton(
        icon: Icon(Icons.list),
        tooltip: 'Opens Drawer',
        onPressed: () {},
      ),
      IconButton(
        icon: Icon(Icons.alarm_add),
        tooltip: 'Opens Clock',
        onPressed: () {},
      )
    ];
// Calling the composite layout widget
AppBarWithTabsAndDrawer(appBarparams, appBarIcons, tabs, userInfo,
            drawerList, onclickLeftNav))

Author:
Rishabh Thakur (Composite Widget)
Karan (AppBar)
Ishita (TabBar)
*/

import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/color.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;
import 'package:flutter_catalogue_widgets/custom-appBar.dart';
import 'package:flutter_catalogue_widgets/custom-drawer.dart';
import 'package:flutter_catalogue_widgets/globals.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';


class AppBarWithTabsAndDrawer extends StatefulWidget {
 final AppBarParameters appBarparams;
 final List<Widget> appBarIcons;
 final List<TabBarProducts> tabsInfo;
 final DrawerHeaderParameters userInfo;
 final List<DrawerListItems> listItems;
 final Function(int) leftNavRouting;
  AppBarWithTabsAndDrawer(this.appBarparams, this.appBarIcons, this.tabsInfo,
      this.userInfo, this.listItems, this.leftNavRouting);

  @override
  State<StatefulWidget> createState() {
    return _TestClass(this.appBarparams, this.appBarIcons, this.tabsInfo,
        this.userInfo, this.listItems, this.leftNavRouting);
  }
}

class _TestClass extends State<AppBarWithTabsAndDrawer>
    with SingleTickerProviderStateMixin {
  AppBarParameters appBarparams;
  List<Widget> appBarIcons;
  List<TabBarProducts> tabsInfo;
  DrawerHeaderParameters userInfo;
  List<DrawerListItems> listItems;
  Function(int) leftNavRouting;
  _TestClass(this.appBarparams, this.appBarIcons, this.tabsInfo, this.userInfo,
      this.listItems, this.leftNavRouting);

  @override
  void initState() {
    super.initState();
    tabControllerForCompositeWidget =
        TabController(initialIndex: 0, vsync: this, length: tabsInfo.length);
  }

  @override
  void dispose() {
    tabControllerForCompositeWidget.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    print(tabsInfo);
    List<Tab> tabList = [];
    List<Widget> tabWidgets = [];
    var tab;
    for (var i = 0; i < tabsInfo.length; i++) {
      tab = new Tab(
          text: tabsInfo[i].text,
          icon: tabsInfo[i].icons != null ? tabsInfo[i].icons : Icons.favorite);
      tabList.add(tab);
    }
    for (var i = 0; i < tabsInfo.length; i++) {
      tab = tabsInfo[i].widget;
      tabWidgets.add(tab);
    }
    // If the user doesn't pass a Tab Bar as part of parameters
    if (appBarparams.bottom == null) {
      appBarparams.bottom = TabBar(
        controller: tabControllerForCompositeWidget,
        labelColor: SalesforceColor.white,
        indicatorColor: SalesforceColor.black,
        unselectedLabelColor: SalesforceColor.orange,
        indicator: BoxDecoration(
          boxShadow: [
            BoxShadow(color: SalesforceColor.orange, offset: cons.offsetDefault)
          ],
          color: SalesforceColor.darkGrey,
        ),
        tabs: tabList,
      );
    }

    return Scaffold(
      drawer: CustomDrawer(listItems, leftNavRouting, userInfo),
      appBar: customAppBar(appBarIcons, appBarparams),
      body: new TabBarView(
        children: tabWidgets,
        controller: tabControllerForCompositeWidget,
      ),
    );
  }
}
